/******************************************************************************/
/*                                                                            */
/*                                SWK_BIND.C                                  */
/*                                ----------                                  */
/*                                                                            */
/*                       Binding fr SOUNDWORKER V1.1                         */
/*                                                                            */
/*                            Sprache: Sozobon C                              */
/*                                                                            */
/******************************************************************************/

#ifndef STRING_H
#include <string.h>
#endif

#ifndef OSBIND_H
#include <osbind.h>
#endif



/******************************************************************************/
/*                                                                            */
/*   Wird das AUDIOFUN-File zum Programm gelinkt, mu folgende Struktur als   */
/*    extern deklariert werden. Die Funktion SWK_LOAD kann dann entfallen.    */
/*                                                                            */
/******************************************************************************/

/* extern */ struct swk
{
   char id[18];
   int  in_out[3];
   int  time[3];
   long execute[3];
   int  last;
   int  ret_0;
   int  ret_1;
   long swk_on;
   long swk_off;
   long joy_on;
   long joy_off;
   int  joy_mode;
   int  swk_prog[2479];
} swk;



/******************************************************************************/
/*                                                                            */
/*                                   SWK_LOAD                                 */
/*                                                                            */
/*                  Eingabe: char *filename                                   */
/*                                                                            */
/*                  Ausgabe:    0 -> erfolgreich geladen                      */
/*                          +/- 1 -> falsche Datei                            */
/*                          sonst -> GEMDOS-Fehlermeldung                     */
/*                                                                            */
/******************************************************************************/

int swk_load(filename)
char *filename;
{
   register int count, handle;
   register long size;

   size = sizeof(swk);

   handle = Fopen(filename, 0);

   if(handle > 0)
   {
      count = (int) Fread(handle, size, &swk);
      Fclose(handle);

      if(count == (int) size)
         return(strcmp(swk.id, "SOUNDWORKER V1.1"));
      else
         return(-1);
   }
   return(handle);
}



/******************************************************************************/
/*                                                                            */
/*                                   SWK_START                                */
/*                                                                            */
/******************************************************************************/

void swk_start()
{
   Supexec(&swk.swk_on);
}



/******************************************************************************/
/*                                                                            */
/*                                   SWK_STOP                                 */
/*                                                                            */
/******************************************************************************/

void swk_stop()
{
   Supexec(&swk.swk_off);
}



/******************************************************************************/
/*                                                                            */
/*                                   SWK_PLAY                                 */
/*                                                                            */
/*       Eingabe: channel ->     0 ... 2                                      */
/*                   part -> +/- 1 ... 8 startet den Kanal                    */
/*                                       sonst  stummschalten                 */
/*                                                                            */
/******************************************************************************/

void swk_play(channel, part)
int channel, part;
{
   if((channel >= 0) && (channel <= 2))
      swk.in_out[channel] = part;
}



/******************************************************************************/
/*                                                                            */
/*                                   SWK_TILL                                 */
/*                                                                            */
/*        Eingabe: channel -> 0 ... 2                                         */
/*                    last -> Anzahl der zu spielenden Takte                  */
/*                                                                            */
/******************************************************************************/

void swk_till(channel, last)
int channel, last;
{
   if((channel >= 0) && (channel <= 2))
      swk.time[channel] = last;
}



/******************************************************************************/
/*                                                                            */
/*                                   SWK_EXEC                                 */
/*                                                                            */
/*     Eingabe: channel -> 0 ... 2                                            */
/*                begin -> Taktnummer zum Starten der Routine                 */
/*              routine -> Startadresse der Routine                           */
/*                                                                            */
/******************************************************************************/

void swk_exec(channel, begin, routine)
int channel, begin;
long routine;
{
   if((channel >= 0) && (channel <= 2))
   {
      swk.time[channel] = begin;
      swk.execute[channel] = routine;
   }
}



/******************************************************************************/
/*                                                                            */
/*                                   SWK_TIME                                 */
/*                                                                            */
/*          Eingabe: channel -> 0 ... 2                                       */
/*                                                                            */
/*          Ausgabe: momentan gespielter Takt oder Null, wenn stumm           */
/*                   -1: ungltige Kanalnummer                                */
/*                                                                            */
/******************************************************************************/

int swk_time(channel)
int channel;
{
   if((channel >= 0) && (channel <= 2))
      return(swk.in_out[channel] & 0x00FF);
   else
      return(-1);
}



/******************************************************************************/
/*                                                                            */
/*                                   SWK_PART                                 */
/*                                                                            */
/*         Eingabe: channel -> 0 ... 2                                        */
/*                                                                            */
/*         Ausgabe: momentan gespielter Part oder Null, wenn stumm            */
/*                  -1: ungltige Kanalnummer                                 */
/*                                                                            */
/******************************************************************************/

int swk_part(channel)
int channel;
{
   if((channel >= 0) && (channel <= 2))
      return(swk.in_out[channel] >> 8);
   else
      return(-1);
}



/******************************************************************************/
/*                                                                            */
/*                                   JOY_START                                */
/*                                                                            */
/******************************************************************************/

void joy_start(joy_mode)
int joy_mode;
{
   swk.joy_mode = joy_mode;
   Supexec(&swk.joy_on);
}



/******************************************************************************/
/*                                                                            */
/*                                   JOY_STOP                                 */
/*                                                                            */
/******************************************************************************/

void joy_stop()
{
   Supexec(&swk.joy_off);
}



/******************************************************************************/
/*                                                                            */
/*                                 JOY_LAST                                   */
/*                                                                            */
/******************************************************************************/

int joy_last()
{
   return(swk.last);
}



/******************************************************************************/
/*                                                                            */
/*                                   JOY_0                                    */
/*                                                                            */
/******************************************************************************/

int joy_0()
{
   return(swk.ret_0);
}




/******************************************************************************/
/*                                                                            */
/*                                   JOY_1                                    */
/*                                                                            */
/******************************************************************************/

int joy_1()
{
   return(swk.ret_1);
}





/* EOF */
